@@ -183,7 +183,7 @@ g_typelib_check_sanity (void)
   CHECK_SIZE (PropertyBlob, 16);
   CHECK_SIZE (SignalBlob, 16);
   CHECK_SIZE (VFuncBlob, 20);
-  CHECK_SIZE (ObjectBlob, 44);
+  CHECK_SIZE (ObjectBlob, 60);
   CHECK_SIZE (InterfaceBlob, 40);
   CHECK_SIZE (ConstantBlob, 24);
   CHECK_SIZE (AttributeBlob, 12);
@@ -288,12 +288,13 @@ validate_header (ValidateContext  *ctx,
 
     }
 
-  if (header->major_version != 2 || header->minor_version != 0)
+  if (header->major_version != 3 || header->minor_version != 0)
     {
       g_set_error (error,
 		   G_TYPELIB_ERROR,
 		   G_TYPELIB_ERROR_INVALID_HEADER,
-		   "Version mismatch");
+		   "Version mismatch; expected 3, found %d",
+		   header->major_version);
       return FALSE;
 
     }
@@ -832,13 +833,16 @@ validate_function_blob (ValidateContext *ctx,
       iface_type = get_type_blob (typelib, simple, error);
       if (!iface_type)
 	return FALSE;
-      if (!(iface_type->tag == GI_TYPE_TAG_INTERFACE))
+      if (iface_type->tag != GI_TYPE_TAG_INTERFACE &&
+          (container_type == BLOB_TYPE_OBJECT ||
+           container_type == BLOB_TYPE_INTERFACE))
 	{
 	  g_set_error (error,
 		       G_TYPELIB_ERROR,
 		       G_TYPELIB_ERROR_INVALID,
-		       "Invalid return type %d for constructor",
-		       iface_type->tag);
+		       "Invalid return type '%s' for constructor '%s'",
+		       g_type_tag_to_string (iface_type->tag),
+		       get_string_nofail (typelib, blob->symbol));
 	  return FALSE;
 	}
     }
@@ -905,17 +909,8 @@ validate_constant_blob (GTypelib     *typelib,
     4, /* UINT32 */
     8, /* INT64 */
     8, /* UINT64 */
-    sizeof (gshort),
-    sizeof (gushort),
-    sizeof (gint),
-    sizeof (guint),
-    sizeof (glong),
-    sizeof (gulong),
-    sizeof (gssize),
-    sizeof (gsize),
     sizeof (gfloat),
     sizeof (gdouble),
-    sizeof (time_t),
     0, /* GTYPE */
     0, /* UTF8 */
     0, /* FILENAME */
@@ -929,6 +924,8 @@ validate_constant_blob (GTypelib     *typelib,
   ConstantBlob *blob;
   SimpleTypeBlob *type;
 
+  g_assert (G_N_ELEMENTS (value_size) == GI_TYPE_TAG_ERROR + 1);
+
   if (typelib->len < offset + sizeof (ConstantBlob))
     {
       g_set_error (error,
