@@ -255,6 +255,17 @@ foo_object_read (FooObject *object, int offset, int length)
 
 }
 
+/**
+ * foo_object_skipped_method: (skip)
+ * @object: obj
+ *
+ * This is only useful from C.
+ */
+void
+foo_object_skipped_method (FooObject *object)
+{
+}
+
 G_DEFINE_ABSTRACT_TYPE (FooSubobject, foo_subobject, FOO_TYPE_OBJECT);
 
 static void
@@ -443,6 +454,16 @@ foo_test_string_array (char **array)
 {
 }
 
+/**
+ * foo_test_array:
+ * Returns: (element-type utf8) (transfer container):
+ */
+GArray *
+foo_test_array (void)
+{
+  return NULL;
+}
+
 /**
  * foo_rectangle_add:
  * @r1: (inout): add to this rect
@@ -600,3 +621,8 @@ void
 foo_skip_me (FooSkippable fs)
 {
 }
+
+/**
+ * FooForeignStruct: (foreign)
+ *
+ */
